@@ -12,6 +12,7 @@
 /*************************************************************************/
 
 #include <link-grammar/api.h>
+#include "error.h"
 #include "preparation.h"
 #ifdef USE_SAT_SOLVER
 #include "sat-solver/sat-encoder.h"
@@ -947,6 +948,10 @@ Linkage linkage_create(int k, Sentence sent, Parse_Options opts)
 	return linkage;
 }
 
+int linkage_get_current_sublinkage(Linkage linkage) { 
+	return linkage->current; 
+} 
+
 int linkage_set_current_sublinkage(Linkage linkage, int index)
 {
 	if ((index < 0) ||
@@ -981,7 +986,7 @@ void linkage_delete(Linkage linkage)
 
 	for (i=0; i<linkage->num_words; ++i)
 	{
-		exfree((char *) linkage->word[i], strlen(linkage->word[i])+1);
+		exfree((void *) linkage->word[i], strlen(linkage->word[i])+1);
 	}
 	exfree(linkage->word, sizeof(char *)*linkage->num_words);
 
@@ -1001,7 +1006,7 @@ void linkage_delete(Linkage linkage)
 			post_process_free_data(&s->pp_data);
 		}
 		if (s->violation != NULL) {
-			exfree((char *) s->violation, sizeof(char)*(strlen(s->violation)+1));
+			exfree((void *) s->violation, sizeof(char)*(strlen(s->violation)+1));
 		}
 	}
 	exfree(linkage->sublinkage, sizeof(Sublinkage)*linkage->num_sublinkages);
@@ -1315,7 +1320,7 @@ void linkage_post_process(Linkage linkage, Postprocessor * postprocessor)
 		}
 		if (subl->violation != NULL)
 		{
-			exfree((char *)subl->violation, sizeof(char)*(strlen(subl->violation)+1));
+			exfree((void *)subl->violation, sizeof(char)*(strlen(subl->violation)+1));
 			subl->violation = NULL;
 		}
 
