@@ -10,20 +10,10 @@
 /* forms, with or without modification, subject to certain conditions.   */
 /*                                                                       */
 /*************************************************************************/
-#ifndef _ERRORH_
-#define _ERRORH_
+#ifndef _LINK_GRAMMAR_ERROR_H_
+#define _LINK_GRAMMAR_ERROR_H_
 
 #include "link-includes.h"
-
-#if     __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
-#define GNUC_PRINTF( format_idx, arg_idx )    \
-  __attribute__((__format__ (__printf__, format_idx, arg_idx)))
-#else
-#define GNUC_PRINTF( format_idx, arg_idx )
-#endif
-
 void error_report_set_sentence(const Sentence s);
-void prt_error(const char *fmt, ...) GNUC_PRINTF(1,2);
-
 #endif
 
