@@ -23,8 +23,8 @@ LINK_BEGIN_DECLS
 *
 ***********************************************************************/
 
-link_public_api(void)
-     lperror_clear(void);  /* -- deprecated/obsolete */
+link_public_api(const char *)
+	linkgrammar_get_version(void);
 
 /**********************************************************************
 *
@@ -46,6 +46,16 @@ link_public_api(int)
 link_public_api(int)
      dictionary_get_max_cost(Dictionary dict);
 
+link_public_api(void)
+     dictionary_set_data_dir(const char * path);
+link_public_api(char *)
+     dictionary_get_data_dir(void);
+
+link_public_api(int)
+     dictionary_is_past_tense_form(Dictionary dict, const char * str);
+link_public_api(int)
+     dictionary_is_entity(Dictionary dict, const char * str);
+
 /**********************************************************************
 *
 * Functions to manipulate Parse Options
@@ -231,6 +241,8 @@ typedef struct Linkage_s * Linkage;
 
 link_public_api(Linkage)
      linkage_create(int index, Sentence sent, Parse_Options opts);
+link_public_api(int) 
+     linkage_get_current_sublinkage(Linkage linkage); 
 link_public_api(int)
      linkage_set_current_sublinkage(Linkage linkage, int index);
 link_public_api(void)
@@ -314,9 +326,6 @@ link_public_api(void)
 link_public_api(void)
      linkage_post_process(Linkage, PostProcessor *);
 
-link_public_api(void)
-     issue_special_command(char * line, Parse_Options opts, Dictionary dict);
-
 /**********************************************************************
 *
 * Constituent node
@@ -340,7 +349,41 @@ link_public_api(int)
 link_public_api(int)
      linkage_constituent_node_get_end(const CNode *n);
 
-/* from error.c -- these are both obsolete. */
+/**********************************************************************
+*
+* Internal functions -- do not use these in new code!
+* These are not intended for general public use, but are required to 
+* work around certain Micorsoft Windows linking oddities.
+*
+***********************************************************************/
+
+link_public_api(void)
+     parse_options_print_total_time(Parse_Options opts);
+
+#if     __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
+#define GNUC_PRINTF( format_idx, arg_idx )    \
+  __attribute__((__format__ (__printf__, format_idx, arg_idx)))
+#else
+#define GNUC_PRINTF( format_idx, arg_idx )
+#endif
+
+link_public_api(void)
+     prt_error(const char *fmt, ...) GNUC_PRINTF(1,2);
+
+/**********************************************************************
+*
+* Obsolete functions -- do not use these in new code!
+*
+***********************************************************************/
+
+/* This is not intended for general use; its specific to the internals
+ * of the command-line client.  It was exported by accident. */
+link_public_api(void)
+     issue_special_command(char * line, Parse_Options opts, Dictionary dict);
+
+/* These are obsolete, and do nothing. */
+link_public_api(void)
+     lperror_clear(void);
 extern link_public_api(int)
      lperrno;
 extern link_public_api(char)
