@@ -15,16 +15,7 @@
 #define _STRUCTURES_H_
 
 #include "api-types.h"
-
-#if defined(_WIN32)
-#define strncasecmp(a,b,s) strnicmp((a),(b),(s))
-#endif
-
-#if defined(__sun__)
-int strncasecmp(const char *s1, const char *s2, size_t n);
-/* This does not appear to be in string.h header file in sunos
-   (Or in linux when I compile with -ansi) */
-#endif
+#include "utilities.h"  /* Needed for inline defn in Windows */
 
 /*
  Global variable descriptions
@@ -84,22 +75,9 @@ int strncasecmp(const char *s1, const char *s2, size_t n);
 
  is_conjunction[]
     An array of chars, one for each word.  TRUE if the word is a conjunction
-    ("and", "or", "nor", or "but" at the moment).  False otherwise. */
+    ("and", "or", "nor", or "but" at the moment).  False otherwise. 
+*/
 
-#ifndef TRUE
-#define TRUE  1
-#endif
-#ifndef FALSE
-#define FALSE 0
-#endif
-#define OBS
-
-#define assert(ex,string) {                                       \
-    if (!(ex)) {                                                  \
-        printf("Assertion failed: %s\n", string);                 \
-        exit(1);                                                  \
-    }                                                             \
-}
 
 #define NEGATIVECOST -1000000
 /* This is a hack that allows one to discard disjuncts containing
@@ -111,13 +89,6 @@ int strncasecmp(const char *s1, const char *s2, size_t n);
 #define NOCUTOFF 1000
 /* no connector will have cost this high */
 
-#if !defined(MIN)
-#define MIN(X,Y)  ( ((X) < (Y)) ? (X) : (Y))
-#endif
-#if !defined(MAX)
-#define MAX(X,Y)  ( ((X) > (Y)) ? (X) : (Y))
-#endif
-
 #define LEFT_WALL_DISPLAY  ("LEFT-WALL")   /* the string to use to show the wall */
 #define LEFT_WALL_SUPPRESS ("Wd") /* If this connector is used on the wall, */
                                   /* then suppress the display of the wall  */
@@ -192,6 +163,7 @@ typedef signed __int64 s64; /* signed 64-bit integer, even on 32-bit cpus */
 struct Connector_struct
 {
     short label;
+    short hash;
     unsigned char word;
                    /* The nearest word to my left (or right) that
                       this could connect to.  Computed by power pruning */
@@ -206,15 +178,29 @@ struct Connector_struct
     char multi;   /* TRUE if this is a multi-connector */
     Connector * next;
     const char * string;
+
+    /* Hash table next pointer, used only during pruning. */
+    Connector * tableNext;
+    const char * prune_string;
 };
 
+static inline void connector_set_string(Connector *c, const char *s)
+{
+	c->string = s;
+	c->hash = -1;
+}
+static inline const char * connector_get_string(Connector *c)
+{
+	return c->string;
+}
+
 struct Disjunct_struct
 {
     Disjunct *next;
-    short cost;
-    char marked;
     const char * string;
     Connector *left, *right;
+    float cost;
+    char marked;
 };
 
 typedef struct Match_node_struct Match_node;
@@ -257,16 +243,16 @@ typedef struct E_list_struct E_list;
 
 struct Exp_struct
 {
+    Exp * next;
     char type;            /* one of three types, see above */
-    unsigned char cost;   /* The cost of using this expression.
-                             Only used for non-terminals */
     char dir;   /* '-' means to the left, '+' means to right (for connector) */
     char multi; /* TRUE if a multi-connector (for connector)  */
     union {
         E_list * l;       /* only needed for non-terminals */
         char * string;    /* only needed if it's a connector */
     } u;
-    Exp * next;
+    float cost;   /* The cost of using this expression.
+                     Only used for non-terminals */
 };
 
 struct E_list_struct
