@@ -27,13 +27,6 @@
 
 #include "error.h"
 
-#ifndef FALSE
-#define FALSE 0
-#endif
-
-#ifndef TRUE
-#define TRUE 1
-#endif
 
 #ifdef __CYGWIN__
 #define _WIN32 1
@@ -42,17 +35,31 @@
 #ifdef _WIN32
 #include <windows.h>
 
-#ifndef _MSC_VER
-   /* CYGWIN/MINGW compilers don't support the "inline" keyword. */
-#define inline
-#endif
-
 #ifdef _MSC_VER
+/* The Microsoft Visual C compiler doesn't support the "inline" keyword. */
+#define inline
+
+/* Non-standard string functions */
 #define snprintf _snprintf
+#define strcasecmp _stricmp
+#define strncasecmp(a,b,s) strnicmp((a),(b),(s))
+
+/* Strangely, though, no langinfo Windows */
+#define nl_langinfo(X) ""
+
+/* strtok_r is missing in Windows */
+char * strtok_r (char *s, const char *delim, char **saveptr);
+
+/* bzero is missing in Windows */
+#define bzero(b,len) (memset((b), '\0', (len)), (void) 0)
+
+/* Windows doesn't have a thread-safe rand (???) */
+/* XXX FIXME -- this breaks thread safety on windows */
+#define rand_r(seedp) rand()
 #endif
 
 /* CYGWIN on Windows doesn't have UTF8 support, or wide chars ... 
- * However, MS Visual C appearnetly does ... 
+ * However, MS Visual C appearently does ... 
  */
 #ifdef __CYGWIN__
 #define mbtowc(w,s,n)  ({*((char *)(w)) = *(s); 1;})
@@ -69,27 +76,42 @@
 #define towupper  toupper
 #endif
 
-/* strtok_r is missing in Windows */
-char * strtok_r (char *s, const char *delim, char **saveptr);
-
-/* bzero is missing in Windows */
-#define bzero(b,len) (memset((b), '\0', (len)), (void) 0)
-
-/* Windows doesn't have a thread-safe rand (???) */
-/* XXX FIXME -- this breaks thread safety on windows */
-#define rand_r(seedp) rand()
-
 #endif /* _WIN32 */
 
+#if defined(__sun__)
+int strncasecmp(const char *s1, const char *s2, size_t n);
+/* This does not appear to be in string.h header file in sunos
+   (Or in linux when I compile with -ansi) */
+#endif
+
+#ifndef FALSE
+#define FALSE 0
+#endif
+
+#ifndef TRUE
+#define TRUE 1
+#endif
+
+#define assert(ex,string) {                                       \
+    if (!(ex)) {                                                  \
+        prt_error("Assertion failed: %s\n", string);              \
+        exit(1);                                                  \
+    }                                                             \
+}
+
+#if !defined(MIN)
+#define MIN(X,Y)  ( ((X) < (Y)) ? (X) : (Y))
+#endif
+#if !defined(MAX)
+#define MAX(X,Y)  ( ((X) > (Y)) ? (X) : (Y))
+#endif
+
+
 static inline int wctomb_check(char *s, wchar_t wc)
 {
 	int nr = wctomb(s, wc);
 	if (nr < 0) {
-#ifndef _WIN32
 		prt_error("Fatal Error: unknwon character set %s\n", nl_langinfo(CODESET));
-#else
-		prt_error("Fatal Error: unknown character set\n");
-#endif
 		exit(1);
 	}
 	return nr;
@@ -175,9 +197,17 @@ void left_print_string(FILE* fp, const char *, const char *);
 void init_memusage(void);
 void * xalloc(size_t);
 void * xrealloc(void *, size_t oldsize, size_t newsize);
-void xfree(void *, size_t);
 void * exalloc(size_t);
+
+#define TRACK_SPACE_USAGE
+#ifdef TRACK_SPACE_USAGE
+void xfree(void *, size_t);
 void exfree(void *, size_t);
+#else /* TRACK_SPACE_USAGE */
+static inline void xfree(void *p, size_t sz) { free(p); }
+static inline void exfree(void *p, size_t sz) { free(p); };
+#endif /* TRACK_SPACE_USAGE */
+
 size_t get_space_in_use(void);
 size_t get_max_space_used(void);
 
@@ -186,7 +216,6 @@ char * get_default_locale(void);
 char * join_path(const char * prefix, const char * suffix);
 
 FILE *dictopen(const char *filename, const char *how);
-void set_data_dir(const char * path);
 
 /**
  * Returns the smallest power of two that is at least i and at least 1
