@@ -76,14 +76,17 @@ Connector * connector_new(void)
 	c->length_limit = UNLIMITED_LEN;
 	c->string = "";
 	c->label = 0;
+	c->hash = -1;
 	c->priority = THIN_priority;
 	c->multi = FALSE;
 	c->next = NULL;
+	c->tableNext = NULL;
 	return c;
 }
 
 Connector * init_connector(Connector *c)
 {
+	c->hash = -1;
 	c->length_limit = UNLIMITED_LEN;
 	return c;
 }
@@ -192,7 +195,7 @@ void exfree_connectors(Connector *e)
 	Connector * n;
 	for(;e != NULL; e = n) {
 		n = e->next;
-		exfree((char *) e->string, sizeof(char)*(strlen(e->string)+1));
+		exfree((void *) e->string, sizeof(char)*(strlen(e->string)+1));
 		exfree(e, sizeof(Connector));
 	}
 }
@@ -237,7 +240,7 @@ void exfree_link(Link * l)
 {
 	exfree_connectors(l->rc);
 	exfree_connectors(l->lc);
-	exfree((char *)l->name, sizeof(char)*(strlen(l->name)+1));
+	exfree((void *)l->name, sizeof(char)*(strlen(l->name)+1));
 	exfree(l, sizeof(Link));
 }
 
@@ -569,7 +572,7 @@ int word_contains(const char * word, const char * macro, Dictionary dict)
 #define PAST_TENSE_FORM_MARKER "<marker-past>"
 #define ENTITY_MARKER          "<marker-entity>"
 
-int is_past_tense_form(const char * str, Dictionary dict)
+int dictionary_is_past_tense_form(Dictionary dict, const char * str)
 {
 	if (word_contains(str, PAST_TENSE_FORM_MARKER, dict) == 1)
 		return 1;
@@ -577,12 +580,12 @@ int is_past_tense_form(const char * str, Dictionary dict)
 }
 
 /**
- * is_entity - Return true if word is entity.
+ * dictionary_is_entity - Return true if word is entity.
  * Entities are proper names (geographical names,
  * names of people), street addresses, phone numbers,
  * etc.
  */
-int is_entity(const char * str, Dictionary dict)
+int dictionary_is_entity(Dictionary dict, const char * str)
 {
 	if (word_contains(str, ENTITY_MARKER, dict) == 1)
 		return 1;
